summaryrefslogtreecommitdiffstats
path: root/src/projects
diff options
context:
space:
mode:
Diffstat (limited to 'src/projects')
-rw-r--r--src/projects/base_k3bdatavolumedescwidget.ui2
-rw-r--r--src/projects/k3baudioburndialog.cpp2
-rw-r--r--src/projects/k3baudiodatasourceviewitem.cpp2
-rw-r--r--src/projects/k3baudioeditorwidget.cpp26
-rw-r--r--src/projects/k3baudiotrackaddingdialog.cpp22
-rw-r--r--src/projects/k3baudiotrackplayer.cpp6
-rw-r--r--src/projects/k3baudiotracktrmlookupdialog.cpp2
-rw-r--r--src/projects/k3baudiotrackview.cpp2
-rw-r--r--src/projects/k3baudiotrackviewitem.cpp2
-rw-r--r--src/projects/k3bbootimageview.cpp2
-rw-r--r--src/projects/k3bdataadvancedimagesettingswidget.cpp8
-rw-r--r--src/projects/k3bdataburndialog.cpp4
-rw-r--r--src/projects/k3bdatadirtreeview.cpp8
-rw-r--r--src/projects/k3bdatafileview.cpp2
-rw-r--r--src/projects/k3bdataimagesettingswidget.cpp2
-rw-r--r--src/projects/k3bdatapropertiesdialog.cpp4
-rw-r--r--src/projects/k3bdataurladdingdialog.cpp52
-rw-r--r--src/projects/k3bdataviewitem.cpp2
-rw-r--r--src/projects/k3bdvdburndialog.cpp4
-rw-r--r--src/projects/k3bfillstatusdisplay.cpp28
-rw-r--r--src/projects/k3bmixedburndialog.cpp2
-rw-r--r--src/projects/k3bmixeddirtreeview.cpp4
-rw-r--r--src/projects/k3bmovixburndialog.cpp4
-rw-r--r--src/projects/k3bmovixdvdburndialog.cpp4
-rw-r--r--src/projects/k3bmovixlistview.cpp4
-rw-r--r--src/projects/k3bmusicbrainzjob.cpp10
-rw-r--r--src/projects/k3bprojectburndialog.cpp4
-rw-r--r--src/projects/k3bvcdburndialog.cpp18
-rw-r--r--src/projects/k3bvcdlistview.cpp2
-rw-r--r--src/projects/k3bvcdtrackdialog.cpp10
-rw-r--r--src/projects/k3bvideodvdburndialog.cpp4
31 files changed, 124 insertions, 124 deletions
diff --git a/src/projects/base_k3bdatavolumedescwidget.ui b/src/projects/base_k3bdatavolumedescwidget.ui
index ba918e2..ee29467 100644
--- a/src/projects/base_k3bdatavolumedescwidget.ui
+++ b/src/projects/base_k3bdatavolumedescwidget.ui
@@ -134,7 +134,7 @@
<property name="text">
<string>Volume set &amp;number:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="buddy" stdset="0">
diff --git a/src/projects/k3baudioburndialog.cpp b/src/projects/k3baudioburndialog.cpp
index 0634caa..4f1a40b 100644
--- a/src/projects/k3baudioburndialog.cpp
+++ b/src/projects/k3baudioburndialog.cpp
@@ -63,7 +63,7 @@ K3bAudioBurnDialog::K3bAudioBurnDialog(K3bAudioDoc* _doc, TQWidget *parent, cons
setTitle( i18n("Audio Project"),
i18n("1 track (%1 minutes)", "%n tracks (%1 minutes)",
- m_doc->numOfTracks() ).tqarg(m_doc->length().toString()) );
+ m_doc->numOfTracks() ).arg(m_doc->length().toString()) );
TQSpacerItem* spacer = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
m_optionGroupLayout->addItem( spacer );
diff --git a/src/projects/k3baudiodatasourceviewitem.cpp b/src/projects/k3baudiodatasourceviewitem.cpp
index 6609d00..04371b1 100644
--- a/src/projects/k3baudiodatasourceviewitem.cpp
+++ b/src/projects/k3baudiodatasourceviewitem.cpp
@@ -89,7 +89,7 @@ void K3bAudioDataSourceViewItem::setText( int col, const TQString& text )
bool K3bAudioDataSourceViewItem::animate()
{
if( source()->length() == 0 && source()->isValid() ) {
- TQString icon = TQString( "kde%1" ).tqarg( m_animationCounter );
+ TQString icon = TQString( "kde%1" ).arg( m_animationCounter );
setPixmap( 4, SmallIcon( icon ) );
m_animationCounter++;
if ( m_animationCounter > 6 )
diff --git a/src/projects/k3baudiotrackaddingdialog.cpp b/src/projects/k3baudiotrackaddingdialog.cpp
index 5e5ca7e..42fe2ce 100644
--- a/src/projects/k3baudiotrackaddingdialog.cpp
+++ b/src/projects/k3baudiotrackaddingdialog.cpp
@@ -104,7 +104,7 @@ int K3bAudioTrackAddingDialog::addUrls( const KURL::List& urls,
dlg.m_trackAfter = afterTrack;
dlg.m_parentTrack = parentTrack;
dlg.m_sourceAfter = afterSource;
- dlg.m_infoLabel->setText( i18n("Adding files to project \"%1\"...").tqarg(doc->URL().fileName()) );
+ dlg.m_infoLabel->setText( i18n("Adding files to project \"%1\"...").arg(doc->URL().fileName()) );
dlg.m_busyWidget->showBusy(true);
TQTimer::singleShot( 0, &dlg, TQT_SLOT(slotAddUrls()) );
@@ -113,23 +113,23 @@ int K3bAudioTrackAddingDialog::addUrls( const KURL::List& urls,
TQString message;
if( !dlg.m_unreadableFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("Insufficient permissions to read the following files") )
- .tqarg( dlg.m_unreadableFiles.join( "<br>" ) );
+ .arg( i18n("Insufficient permissions to read the following files") )
+ .arg( dlg.m_unreadableFiles.join( "<br>" ) );
if( !dlg.m_notFoundFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("Unable to find the following files") )
- .tqarg( dlg.m_notFoundFiles.join( "<br>" ) );
+ .arg( i18n("Unable to find the following files") )
+ .arg( dlg.m_notFoundFiles.join( "<br>" ) );
if( !dlg.m_nonLocalFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("No non-local files supported") )
- .tqarg( dlg.m_unreadableFiles.join( "<br>" ) );
+ .arg( i18n("No non-local files supported") )
+ .arg( dlg.m_unreadableFiles.join( "<br>" ) );
if( !dlg.m_unsupportedFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br><i>%2</i><br>%3")
- .tqarg( i18n("Unable to handle the following files due to an unsupported format" ) )
- .tqarg( i18n("You may manually convert these audio files to wave using another "
+ .arg( i18n("Unable to handle the following files due to an unsupported format" ) )
+ .arg( i18n("You may manually convert these audio files to wave using another "
"application supporting the audio format and then add the wave files "
"to the K3b project.") )
- .tqarg( dlg.m_unsupportedFiles.join( "<br>" ) );
+ .arg( dlg.m_unsupportedFiles.join( "<br>" ) );
if( !message.isEmpty() )
KMessageBox::detailedSorry( parent, i18n("Problems while adding files to the project."), message );
@@ -162,7 +162,7 @@ void K3bAudioTrackAddingDialog::slotAddUrls()
}
}
- m_infoLabel->setText( i18n("Analysing file '%1'...").tqarg( url.fileName() ) );
+ m_infoLabel->setText( i18n("Analysing file '%1'...").arg( url.fileName() ) );
if( !url.isLocalFile() ) {
valid = false;
diff --git a/src/projects/k3baudiotrackplayer.cpp b/src/projects/k3baudiotrackplayer.cpp
index adc1e41..c73342c 100644
--- a/src/projects/k3baudiotrackplayer.cpp
+++ b/src/projects/k3baudiotrackplayer.cpp
@@ -185,9 +185,9 @@ void K3bAudioTrackPlayer::playTrack( K3bAudioTrack* track )
// we show the currently playing track as a tooltip on the slider
TQToolTip::remove( d->seekSlider );
TQToolTip::add( d->seekSlider, i18n("Playing track %1: %2 - %3")
- .tqarg(track->trackNumber())
- .tqarg(track->artist())
- .tqarg(track->title()) );
+ .arg(track->trackNumber())
+ .arg(track->artist())
+ .arg(track->title()) );
d->seekSlider->setMaxValue( track->length().totalFrames() );
m_currentTrack = track;
d->paused = true;
diff --git a/src/projects/k3baudiotracktrmlookupdialog.cpp b/src/projects/k3baudiotracktrmlookupdialog.cpp
index 0bf23ec..85a651b 100644
--- a/src/projects/k3baudiotracktrmlookupdialog.cpp
+++ b/src/projects/k3baudiotracktrmlookupdialog.cpp
@@ -122,7 +122,7 @@ void K3bAudioTrackTRMLookupDialog::slotTrackFinished( K3bAudioTrack* track, bool
{
if( !success )
K3bPassivePopup::showPopup( i18n("Track %1 was not found in the MusicBrainz database.")
- .tqarg( track->trackNumber()),
+ .arg( track->trackNumber()),
i18n("Audio Project") );
}
diff --git a/src/projects/k3baudiotrackview.cpp b/src/projects/k3baudiotrackview.cpp
index 23f3478..2e67aee 100644
--- a/src/projects/k3baudiotrackview.cpp
+++ b/src/projects/k3baudiotrackview.cpp
@@ -487,7 +487,7 @@ void K3bAudioTrackView::slotTrackChanged( K3bAudioTrack* track )
item->showSources(true);
// the length might have changed
- item->tqrepaint();
+ item->repaint();
// FIXME: only do this if the position really changed
// move the item if the position has changed
diff --git a/src/projects/k3baudiotrackviewitem.cpp b/src/projects/k3baudiotrackviewitem.cpp
index 24d6f48..3027eac 100644
--- a/src/projects/k3baudiotrackviewitem.cpp
+++ b/src/projects/k3baudiotrackviewitem.cpp
@@ -194,7 +194,7 @@ bool K3bAudioTrackViewItem::animate()
item = item->nextSibling();
}
if( animate ) {
- TQString icon = TQString( "kde%1" ).tqarg( m_animationCounter );
+ TQString icon = TQString( "kde%1" ).arg( m_animationCounter );
setPixmap( 4, SmallIcon( icon ) );
m_animationCounter++;
if ( m_animationCounter > 6 )
diff --git a/src/projects/k3bbootimageview.cpp b/src/projects/k3bbootimageview.cpp
index 92b4c87..cf2f086 100644
--- a/src/projects/k3bbootimageview.cpp
+++ b/src/projects/k3bbootimageview.cpp
@@ -61,7 +61,7 @@ public:
return i18n("None");
}
else if( col == 1 )
- return TQString( "%1 KB" ).tqarg( m_image->size()/1024 );
+ return TQString( "%1 KB" ).arg( m_image->size()/1024 );
else if( col == 2 )
return m_image->localPath();
else
diff --git a/src/projects/k3bdataadvancedimagesettingswidget.cpp b/src/projects/k3bdataadvancedimagesettingswidget.cpp
index 782d898..9ecc9bc 100644
--- a/src/projects/k3bdataadvancedimagesettingswidget.cpp
+++ b/src/projects/k3bdataadvancedimagesettingswidget.cpp
@@ -130,7 +130,7 @@ public:
protected:
void stateChange( bool on ) {
- // enable or disable all tqchildren
+ // enable or disable all children
TQListViewItem* item = firstChild();
while( item ) {
if( PrivateCheckViewItem* pi = dynamic_cast<PrivateCheckViewItem*>(item) )
@@ -205,13 +205,13 @@ K3bDataAdvancedImageSettingsWidget::K3bDataAdvancedImageSettingsWidget( TQWidget
i18n("ISO Level") );
m_radioIsoLevel3 = new TQCheckListItem( m_isoLevelController,
- i18n("Level %1").tqarg(3),
+ i18n("Level %1").arg(3),
TQCheckListItem::RadioButton );
m_radioIsoLevel2 = new TQCheckListItem( m_isoLevelController,
- i18n("Level %1").tqarg(2),
+ i18n("Level %1").arg(2),
TQCheckListItem::RadioButton );
m_radioIsoLevel1 = new TQCheckListItem( m_isoLevelController,
- i18n("Level %1").tqarg(1),
+ i18n("Level %1").arg(1),
TQCheckListItem::RadioButton );
m_isoLevelController->setOpen(true);
diff --git a/src/projects/k3bdataburndialog.cpp b/src/projects/k3bdataburndialog.cpp
index 2b4375f..38260e3 100644
--- a/src/projects/k3bdataburndialog.cpp
+++ b/src/projects/k3bdataburndialog.cpp
@@ -69,7 +69,7 @@ K3bDataBurnDialog::K3bDataBurnDialog(K3bDataDoc* _doc, TQWidget *parent, const c
{
prepareGui();
- setTitle( i18n("Data Project"), i18n("Size: %1").tqarg( KIO::convertSize(_doc->size()) ) );
+ setTitle( i18n("Data Project"), i18n("Size: %1").arg( KIO::convertSize(_doc->size()) ) );
// for now we just put the verify checkbox on the main page...
m_checkVerify = K3bStdGuiItems::verifyCheckBox( m_optionGroup );
@@ -181,7 +181,7 @@ void K3bDataBurnDialog::slotStartClicked()
if( TQFile::exists( m_tempDirSelectionWidget->tempPath() ) ) {
if( KMessageBox::warningContinueCancel( this,
- i18n("Do you want to overwrite %1?").tqarg(m_tempDirSelectionWidget->tempPath()),
+ i18n("Do you want to overwrite %1?").arg(m_tempDirSelectionWidget->tempPath()),
i18n("File Exists"), i18n("Overwrite") )
== KMessageBox::Continue ) {
// delete the file here to avoid problems with free space in K3bProjectBurnDialog::slotStartClicked
diff --git a/src/projects/k3bdatadirtreeview.cpp b/src/projects/k3bdatadirtreeview.cpp
index 6164aa2..04c6cb9 100644
--- a/src/projects/k3bdatadirtreeview.cpp
+++ b/src/projects/k3bdatadirtreeview.cpp
@@ -249,7 +249,7 @@ void K3bDataDirTreeView::slotDataItemRemoved( K3bDataItem* item )
// we don't get removedInfo for the child items
// so we need to remove them here
- TQPtrListIterator<K3bDataItem> it( dirItem->tqchildren() );
+ TQPtrListIterator<K3bDataItem> it( dirItem->children() );
for( ; it.current(); ++it ) {
if( it.current()->isDir() )
slotDataItemRemoved( it.current() );
@@ -374,9 +374,9 @@ void K3bDataDirTreeView::slotProperties()
if( viewItem && currentItem() != root() ) {
K3bDataPropertiesDialog d( viewItem->dataItem(), this );
if( d.exec() ) {
- tqrepaint();
+ repaint();
if( m_fileView )
- m_fileView->tqrepaint();
+ m_fileView->repaint();
}
}
else
@@ -499,7 +499,7 @@ void K3bDataDirTreeView::slotDocChanged()
// avoid flicker
if( d->lastUpdateVolumeId != m_doc->isoOptions().volumeID() ) {
d->lastUpdateVolumeId = m_doc->isoOptions().volumeID();
- root()->tqrepaint();
+ root()->repaint();
}
}
diff --git a/src/projects/k3bdatafileview.cpp b/src/projects/k3bdatafileview.cpp
index b29f8ad..afe94a3 100644
--- a/src/projects/k3bdatafileview.cpp
+++ b/src/projects/k3bdatafileview.cpp
@@ -165,7 +165,7 @@ void K3bDataFileView::checkForNewItems()
hideEditor();
// add items that are not there yet
- for( TQPtrListIterator<K3bDataItem> it( m_currentDir->tqchildren() ); it.current(); ++it ) {
+ for( TQPtrListIterator<K3bDataItem> it( m_currentDir->children() ); it.current(); ++it ) {
if( !m_itemMap.contains( it.current() ) ) {
slotItemAdded( it.current() );
}
diff --git a/src/projects/k3bdataimagesettingswidget.cpp b/src/projects/k3bdataimagesettingswidget.cpp
index 899993d..918ebdf 100644
--- a/src/projects/k3bdataimagesettingswidget.cpp
+++ b/src/projects/k3bdataimagesettingswidget.cpp
@@ -268,7 +268,7 @@ void K3bDataImageSettingsWidget::slotFilesystemsChanged()
if( s.isEmpty() )
m_comboFilesystems->changeItem( i18n("Custom (ISO9660 only)"), FS_CUSTOM );
else
- m_comboFilesystems->changeItem( i18n("Custom (%1)").tqarg( s.join(", ") ), FS_CUSTOM );
+ m_comboFilesystems->changeItem( i18n("Custom (%1)").arg( s.join(", ") ), FS_CUSTOM );
// see if any of the presets is loaded
m_comboFilesystems->setCurrentItem( FS_CUSTOM );
diff --git a/src/projects/k3bdatapropertiesdialog.cpp b/src/projects/k3bdatapropertiesdialog.cpp
index 2e8ec3a..b1a5794 100644
--- a/src/projects/k3bdatapropertiesdialog.cpp
+++ b/src/projects/k3bdatapropertiesdialog.cpp
@@ -94,7 +94,7 @@ K3bDataPropertiesDialog::K3bDataPropertiesDialog( K3bDataItem* dataItem, TQWidge
KFileItem kFileItem( KFileItem::Unknown, KFileItem::Unknown, KURL::fromPathOrURL(fileItem->localPath()) );
labelMimeType->setPixmap( kFileItem.pixmap(KIcon::SizeLarge) );
if( fileItem->isSymLink() )
- m_labelType->setText( i18n("Link to %1").tqarg(kFileItem.mimeComment()) );
+ m_labelType->setText( i18n("Link to %1").arg(kFileItem.mimeComment()) );
else
m_labelType->setText( kFileItem.mimeComment() );
m_labelLocalName->setText( kFileItem.name() );
@@ -136,7 +136,7 @@ K3bDataPropertiesDialog::K3bDataPropertiesDialog( K3bDataItem* dataItem, TQWidge
if( location.isEmpty() )
location = "/";
m_labelLocation->setText( location );
- extraInfoLabel->setText( TQString( "(%1)" ).tqarg(dataItem->extraInfo()) );
+ extraInfoLabel->setText( TQString( "(%1)" ).arg(dataItem->extraInfo()) );
if( dataItem->extraInfo().isEmpty() )
extraInfoLabel->hide();
diff --git a/src/projects/k3bdataurladdingdialog.cpp b/src/projects/k3bdataurladdingdialog.cpp
index cf57b1d..287191c 100644
--- a/src/projects/k3bdataurladdingdialog.cpp
+++ b/src/projects/k3bdataurladdingdialog.cpp
@@ -57,7 +57,7 @@
K3bDataUrlAddingDialog::K3bDataUrlAddingDialog( K3bDataDoc* doc, TQWidget* parent, const char* name )
: KDialogBase( Plain,
- i18n("Adding files to project '%1'").tqarg(doc->URL().fileName()),
+ i18n("Adding files to project '%1'").arg(doc->URL().fileName()),
Cancel,
Cancel,
parent,
@@ -84,7 +84,7 @@ K3bDataUrlAddingDialog::K3bDataUrlAddingDialog( K3bDataDoc* doc, TQWidget* paren
m_counterLabel = new TQLabel( page );
m_infoLabel = new KSqueezedTextLabel( i18n("Adding files to project '%1'")
- .tqarg(doc->URL().fileName()) + "...", page );
+ .arg(doc->URL().fileName()) + "...", page );
m_progressWidget = new KProgress( 0, page );
grid->addWidget( m_counterLabel, 0, 1 );
@@ -169,29 +169,29 @@ TQString K3bDataUrlAddingDialog::resultMessage() const
TQString message;
if( !m_unreadableFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("Insufficient permissions to read the following files") )
- .tqarg( m_unreadableFiles.join( "<br>" ) );
+ .arg( i18n("Insufficient permissions to read the following files") )
+ .arg( m_unreadableFiles.join( "<br>" ) );
if( !m_notFoundFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("Unable to find the following files") )
- .tqarg( m_notFoundFiles.join( "<br>" ) );
+ .arg( i18n("Unable to find the following files") )
+ .arg( m_notFoundFiles.join( "<br>" ) );
if( !m_nonLocalFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("No non-local files supported") )
- .tqarg( m_unreadableFiles.join( "<br>" ) );
+ .arg( i18n("No non-local files supported") )
+ .arg( m_unreadableFiles.join( "<br>" ) );
if( !m_tooBigFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("It is not possible to add files bigger than %1").tqarg(KIO::convertSize(0xFFFFFFFF)) )
- .tqarg( m_tooBigFiles.join( "<br>" ) );
+ .arg( i18n("It is not possible to add files bigger than %1").arg(KIO::convertSize(0xFFFFFFFF)) )
+ .arg( m_tooBigFiles.join( "<br>" ) );
if( !m_mkisofsLimitationRenamedFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("Some filenames had to be modified due to limitations in mkisofs") )
- .tqarg( m_mkisofsLimitationRenamedFiles.join( "<br>" ) );
+ .arg( i18n("Some filenames had to be modified due to limitations in mkisofs") )
+ .arg( m_mkisofsLimitationRenamedFiles.join( "<br>" ) );
if( !m_invalidFilenameEncodingFiles.isEmpty() )
message += TQString("<p><b>%1:</b><br>%2")
- .tqarg( i18n("The following filenames have an invalid encoding. You may fix this "
+ .arg( i18n("The following filenames have an invalid encoding. You may fix this "
"with the convmv tool") )
- .tqarg( m_invalidFilenameEncodingFiles.join( "<br>" ) );
+ .arg( m_invalidFilenameEncodingFiles.join( "<br>" ) );
return message;
}
@@ -222,7 +222,7 @@ int K3bDataUrlAddingDialog::copyMoveItems( const TQValueList<K3bDataItem*>& item
return 0;
K3bDataUrlAddingDialog dlg( dir->doc(), parent );
- dlg.m_infoLabel->setText( i18n("Moving files to project \"%1\"...").tqarg(dir->doc()->URL().fileName()) );
+ dlg.m_infoLabel->setText( i18n("Moving files to project \"%1\"...").arg(dir->doc()->URL().fileName()) );
dlg.m_copyItems = copy;
for( TQValueList<K3bDataItem*>::const_iterator it = items.begin(); it != items.end(); ++it ) {
@@ -283,9 +283,9 @@ void K3bDataUrlAddingDialog::slotAddUrls()
#if 0
m_infoLabel->setText( url.path() );
if( m_totalFiles == 0 )
- m_counterLabel->setText( TQString("(%1)").tqarg(m_filesHandled) );
+ m_counterLabel->setText( TQString("(%1)").arg(m_filesHandled) );
else
- m_counterLabel->setText( TQString("(%1/%2)").tqarg(m_filesHandled).tqarg(m_totalFiles) );
+ m_counterLabel->setText( TQString("(%1/%2)").arg(m_filesHandled).arg(m_totalFiles) );
#endif
//
@@ -425,8 +425,8 @@ void K3bDataUrlAddingDialog::slotAddUrls()
switch( K3bMultiChoiceDialog::choose( i18n("File already exists"),
i18n("<p>File <em>%1</em> already exists in "
"project folder <em>%2</em>.")
- .tqarg(newName)
- .tqarg('/' + dir->k3bPath()),
+ .arg(newName)
+ .arg('/' + dir->k3bPath()),
TQMessageBox::Warning,
this,
0,
@@ -493,8 +493,8 @@ void K3bDataUrlAddingDialog::slotAddUrls()
"K3b project cannot be resolved."
"<p><b>If you do not intend to enable the option <em>follow symbolic links</em> you may safely "
"ignore this warning and choose to add the link to the project.</b>")
- .tqarg(absFilePath)
- .tqarg(resolved ),
+ .arg(absFilePath)
+ .arg(resolved ),
TQMessageBox::Warning,
this,
0,
@@ -603,9 +603,9 @@ void K3bDataUrlAddingDialog::slotCopyMoveItems()
++m_filesHandled;
m_infoLabel->setText( item->k3bPath() );
if( m_totalFiles == 0 )
- m_counterLabel->setText( TQString("(%1)").tqarg(m_filesHandled) );
+ m_counterLabel->setText( TQString("(%1)").arg(m_filesHandled) );
else
- m_counterLabel->setText( TQString("(%1/%2)").tqarg(m_filesHandled).tqarg(m_totalFiles) );
+ m_counterLabel->setText( TQString("(%1/%2)").arg(m_filesHandled).arg(m_totalFiles) );
if( dir == item->parent() ) {
@@ -623,7 +623,7 @@ void K3bDataUrlAddingDialog::slotCopyMoveItems()
// reuse an existing dir: move all child items into the old dir
//
if( oldItem->isDir() && item->isDir() ) {
- const TQPtrList<K3bDataItem>& cl = dynamic_cast<K3bDirItem*>( item )->tqchildren();
+ const TQPtrList<K3bDataItem>& cl = dynamic_cast<K3bDirItem*>( item )->children();
for( TQPtrListIterator<K3bDataItem> it( cl ); *it; ++it )
m_items.append( tqMakePair( *it, dynamic_cast<K3bDirItem*>( oldItem ) ) );
@@ -661,8 +661,8 @@ void K3bDataUrlAddingDialog::slotCopyMoveItems()
switch( K3bMultiChoiceDialog::choose( i18n("File already exists"),
i18n("<p>File <em>%1</em> already exists in "
"project folder <em>%2</em>.")
- .tqarg( item->k3bName() )
- .tqarg("/" + dir->k3bPath()),
+ .arg( item->k3bName() )
+ .arg("/" + dir->k3bPath()),
TQMessageBox::Warning,
this,
0,
diff --git a/src/projects/k3bdataviewitem.cpp b/src/projects/k3bdataviewitem.cpp
index ae5e7f6..475d411 100644
--- a/src/projects/k3bdataviewitem.cpp
+++ b/src/projects/k3bdataviewitem.cpp
@@ -228,7 +228,7 @@ TQString K3bDataFileViewItem::text( int index ) const
comment = m_pMimeType->name();
if( m_fileItem->isSymLink() )
- return i18n("Link to %1").tqarg(comment);
+ return i18n("Link to %1").arg(comment);
else
return comment;
}
diff --git a/src/projects/k3bdvdburndialog.cpp b/src/projects/k3bdvdburndialog.cpp
index 17ee516..7f04ed4 100644
--- a/src/projects/k3bdvdburndialog.cpp
+++ b/src/projects/k3bdvdburndialog.cpp
@@ -50,7 +50,7 @@ K3bDvdBurnDialog::K3bDvdBurnDialog( K3bDvdDoc* doc, TQWidget *parent, const char
{
prepareGui();
- setTitle( i18n("DVD Project"), i18n("Size: %1").tqarg( KIO::convertSize(doc->size()) ) );
+ setTitle( i18n("DVD Project"), i18n("Size: %1").arg( KIO::convertSize(doc->size()) ) );
// for now we just put the verify checkbox on the main page...
m_checkVerify = K3bStdGuiItems::verifyCheckBox( m_optionGroup );
@@ -283,7 +283,7 @@ void K3bDvdBurnDialog::slotStartClicked()
if( TQFile::exists( m_tempDirSelectionWidget->tempPath() ) ) {
if( KMessageBox::warningContinueCancel( this,
- i18n("Do you want to overwrite %1?").tqarg(m_tempDirSelectionWidget->tempPath()),
+ i18n("Do you want to overwrite %1?").arg(m_tempDirSelectionWidget->tempPath()),
i18n("File Exists"), i18n("Overwrite") )
== KMessageBox::Continue ) {
// delete the file here to avoid problems with free space in K3bProjectBurnDialog::slotStartClicked
diff --git a/src/projects/k3bfillstatusdisplay.cpp b/src/projects/k3bfillstatusdisplay.cpp
index d748dce..967e1d0 100644
--- a/src/projects/k3bfillstatusdisplay.cpp
+++ b/src/projects/k3bfillstatusdisplay.cpp
@@ -129,7 +129,7 @@ void K3bFillStatusDisplayWidget::paintEvent( TQPaintEvent* )
TQPixmap buffer( size() );
buffer.fill( colorGroup().base() );
TQPainter p;
- p.tqbegin( &buffer, TQT_TQOBJECT(this) );
+ p.begin( &buffer, TQT_TQOBJECT(this) );
p.setPen( TQt::black ); // we use a fixed bar color (which is not very nice btw, so we also fix the text color)
long long docSize;
@@ -199,16 +199,16 @@ void K3bFillStatusDisplayWidget::paintEvent( TQPaintEvent* )
TQString overSizeText;
if( d->cdSize.mode1Bytes() >= d->doc->size() )
overSizeText = i18n("Available: %1 of %2")
- .tqarg( d->showTime
- ? i18n("%1 min").tqarg((K3b::Msf( cdSize*60*75 ) - d->doc->length()).toString(false))
+ .arg( d->showTime
+ ? i18n("%1 min").arg((K3b::Msf( cdSize*60*75 ) - d->doc->length()).toString(false))
: KIO::convertSize( TQMAX( (cdSize * 1024LL * 1024LL) - (long long)d->doc->size(), 0LL ) ) )
- .tqarg( d->showTime
- ? i18n("%1 min").tqarg(K3b::Msf( cdSize*60*75 ).toString(false))
+ .arg( d->showTime
+ ? i18n("%1 min").arg(K3b::Msf( cdSize*60*75 ).toString(false))
: KIO::convertSizeFromKB( cdSize * 1024 ) );
else
overSizeText = i18n("Capacity exceeded by %1")
- .tqarg( d->showTime
- ? i18n("%1 min").tqarg( (d->doc->length() - K3b::Msf( cdSize*60*75 ) ).toString(false))
+ .arg( d->showTime
+ ? i18n("%1 min").arg( (d->doc->length() - K3b::Msf( cdSize*60*75 ) ).toString(false))
: KIO::convertSize( (long long)d->doc->size() - (cdSize * 1024LL * 1024LL) ) );
// ====================================================================================
@@ -388,11 +388,11 @@ void K3bFillStatusDisplay::setupPopupMenu()
d->actionAuto = new KRadioAction( i18n("Auto"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAutoSize()),
d->actionCollection, "fillstatus_auto" );
- d->action74Min = new KRadioAction( i18n("%1 MB").tqarg(650), 0, TQT_TQOBJECT(this), TQT_SLOT(slot74Minutes()),
+ d->action74Min = new KRadioAction( i18n("%1 MB").arg(650), 0, TQT_TQOBJECT(this), TQT_SLOT(slot74Minutes()),
d->actionCollection, "fillstatus_74minutes" );
- d->action80Min = new KRadioAction( i18n("%1 MB").tqarg(700), 0, TQT_TQOBJECT(this), TQT_SLOT(slot80Minutes()),
+ d->action80Min = new KRadioAction( i18n("%1 MB").arg(700), 0, TQT_TQOBJECT(this), TQT_SLOT(slot80Minutes()),
d->actionCollection, "fillstatus_80minutes" );
- d->action100Min = new KRadioAction( i18n("%1 MB").tqarg(880), 0, TQT_TQOBJECT(this), TQT_SLOT(slot100Minutes()),
+ d->action100Min = new KRadioAction( i18n("%1 MB").arg(880), 0, TQT_TQOBJECT(this), TQT_SLOT(slot100Minutes()),
d->actionCollection, "fillstatus_100minutes" );
d->actionDvd4_7GB = new KRadioAction( KIO::convertSizeFromKB((int)(4.4*1024.0*1024.0)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDvd4_7GB()),
d->actionCollection, "fillstatus_dvd_4_7gb" );
@@ -460,9 +460,9 @@ void K3bFillStatusDisplay::showSize()
{
d->actionShowMegs->setChecked( true );
- d->action74Min->setText( i18n("%1 MB").tqarg(650) );
- d->action80Min->setText( i18n("%1 MB").tqarg(700) );
- d->action100Min->setText( i18n("%1 MB").tqarg(880) );
+ d->action74Min->setText( i18n("%1 MB").arg(650) );
+ d->action80Min->setText( i18n("%1 MB").arg(700) );
+ d->action100Min->setText( i18n("%1 MB").arg(880) );
d->showTime = false;
d->displayWidget->setShowTime(false);
@@ -548,7 +548,7 @@ void K3bFillStatusDisplay::slotCustomSize()
i18n("<p>Please specify the size of the media. Use suffixes <b>gb</b>,<b>mb</b>, "
"and <b>min</b> for <em>gigabytes</em>, <em>megabytes</em>, and <em>minutes</em>"
" respectively."),
- d->showDvdSizes ? TQString("4%14%2").tqarg(KGlobal::locale()->decimalSymbol()).tqarg(gbS) :
+ d->showDvdSizes ? TQString("4%14%2").arg(KGlobal::locale()->decimalSymbol()).arg(gbS) :
(d->showTime ? TQString("74")+minS : TQString("650")+mbS),
&ok, this, (const char*)0,
new TQRegExpValidator( rx, TQT_TQOBJECT(this) ) );
diff --git a/src/projects/k3bmixedburndialog.cpp b/src/projects/k3bmixedburndialog.cpp
index 2053e32..1446f1f 100644
--- a/src/projects/k3bmixedburndialog.cpp
+++ b/src/projects/k3bmixedburndialog.cpp
@@ -66,7 +66,7 @@ K3bMixedBurnDialog::K3bMixedBurnDialog( K3bMixedDoc* doc, TQWidget *parent, cons
setTitle( i18n("Mixed Project"), i18n("1 track (%1 minutes)",
"%n tracks (%1 minutes)",
- m_doc->numOfTracks()).tqarg(m_doc->length().toString()) );
+ m_doc->numOfTracks()).arg(m_doc->length().toString()) );
m_checkOnlyCreateImage->hide();
diff --git a/src/projects/k3bmixeddirtreeview.cpp b/src/projects/k3bmixeddirtreeview.cpp
index c19bd28..dd644b5 100644
--- a/src/projects/k3bmixeddirtreeview.cpp
+++ b/src/projects/k3bmixeddirtreeview.cpp
@@ -42,7 +42,7 @@ public:
TQString text( int col ) const {
if( col == 0 )
- return i18n("Audio Tracks") + TQString(" (%1)").tqarg(m_doc->audioDoc()->numOfTracks());
+ return i18n("Audio Tracks") + TQString(" (%1)").arg(m_doc->audioDoc()->numOfTracks());
else
return TQString();
}
@@ -97,7 +97,7 @@ void K3bMixedDirTreeView::slotSelectionChanged( TQListViewItem* i )
void K3bMixedDirTreeView::slotNewAudioTracks()
{
// update the tracknumber
- m_audioRootItem->tqrepaint();
+ m_audioRootItem->repaint();
}
#include "k3bmixeddirtreeview.moc"
diff --git a/src/projects/k3bmovixburndialog.cpp b/src/projects/k3bmovixburndialog.cpp
index 4a49d4f..1864745 100644
--- a/src/projects/k3bmovixburndialog.cpp
+++ b/src/projects/k3bmovixburndialog.cpp
@@ -52,7 +52,7 @@ K3bMovixBurnDialog::K3bMovixBurnDialog( K3bMovixDoc* doc, TQWidget* parent, cons
m_tempDirSelectionWidget->setSelectionMode( K3bTempDirSelectionWidget::FILE );
setTitle( i18n("eMovix CD Project"),
- i18n("1 file (%1)", "%n files (%1)", m_doc->movixFileItems().count()).tqarg(KIO::convertSize(m_doc->size())) );
+ i18n("1 file (%1)", "%n files (%1)", m_doc->movixFileItems().count()).arg(KIO::convertSize(m_doc->size())) );
m_movixOptionsWidget = new K3bMovixOptionsWidget( this );
addPage( m_movixOptionsWidget, i18n("eMovix") );
@@ -226,7 +226,7 @@ void K3bMovixBurnDialog::slotStartClicked()
if( TQFile::exists( m_tempDirSelectionWidget->tempPath() ) ) {
if( KMessageBox::warningContinueCancel( this,
- i18n("Do you want to overwrite %1?").tqarg(m_tempDirSelectionWidget->tempPath()),
+ i18n("Do you want to overwrite %1?").arg(m_tempDirSelectionWidget->tempPath()),
i18n("File Exists"), i18n("Overwrite") )
!= KMessageBox::Continue )
return;
diff --git a/src/projects/k3bmovixdvdburndialog.cpp b/src/projects/k3bmovixdvdburndialog.cpp
index 9cc5617..24e3904 100644
--- a/src/projects/k3bmovixdvdburndialog.cpp
+++ b/src/projects/k3bmovixdvdburndialog.cpp
@@ -54,7 +54,7 @@ K3bMovixDvdBurnDialog::K3bMovixDvdBurnDialog( K3bMovixDvdDoc* doc, TQWidget* par
m_tempDirSelectionWidget->setSelectionMode( K3bTempDirSelectionWidget::FILE );
setTitle( i18n("eMovix DVD Project"),
- i18n("1 file (%1)", "%n files (%1)", m_doc->movixFileItems().count()).tqarg(KIO::convertSize(m_doc->size())) );
+ i18n("1 file (%1)", "%n files (%1)", m_doc->movixFileItems().count()).arg(KIO::convertSize(m_doc->size())) );
m_movixOptionsWidget = new K3bMovixOptionsWidget( this );
addPage( m_movixOptionsWidget, i18n("eMovix") );
@@ -193,7 +193,7 @@ void K3bMovixDvdBurnDialog::slotStartClicked()
if( TQFile::exists( m_tempDirSelectionWidget->tempPath() ) ) {
if( KMessageBox::warningContinueCancel( this,
- i18n("Do you want to overwrite %1?").tqarg(m_tempDirSelectionWidget->tempPath()),
+ i18n("Do you want to overwrite %1?").arg(m_tempDirSelectionWidget->tempPath()),
i18n("File Exists"), i18n("Overwrite") )
!= KMessageBox::Continue )
return;
diff --git a/src/projects/k3bmovixlistview.cpp b/src/projects/k3bmovixlistview.cpp
index e43dfd5..44136b5 100644
--- a/src/projects/k3bmovixlistview.cpp
+++ b/src/projects/k3bmovixlistview.cpp
@@ -84,7 +84,7 @@ TQString K3bMovixFileViewItem::text( int col ) const
case 2:
{
if( fileItem()->isSymLink() )
- return i18n("Link to %1").tqarg(const_cast<K3bMovixFileViewItem*>(this)->mimeComment()) + " ";
+ return i18n("Link to %1").arg(const_cast<K3bMovixFileViewItem*>(this)->mimeComment()) + " ";
else
return const_cast<K3bMovixFileViewItem*>(this)->mimeComment() + " ";
}
@@ -139,7 +139,7 @@ TQString K3bMovixSubTitleViewItem::text( int c ) const
case 2:
{
if( fileItem()->subTitleItem()->isSymLink() )
- return i18n("Link to %1").tqarg(const_cast<K3bMovixSubTitleViewItem*>(this)->mimeComment());
+ return i18n("Link to %1").arg(const_cast<K3bMovixSubTitleViewItem*>(this)->mimeComment());
else
return const_cast<K3bMovixSubTitleViewItem*>(this)->mimeComment();
}
diff --git a/src/projects/k3bmusicbrainzjob.cpp b/src/projects/k3bmusicbrainzjob.cpp
index 2074cd2..d39b88c 100644
--- a/src/projects/k3bmusicbrainzjob.cpp
+++ b/src/projects/k3bmusicbrainzjob.cpp
@@ -188,7 +188,7 @@ void K3bMusicBrainzJob::start()
m_trmThread->track = m_tracks.first();
emit infoMessage( i18n("Generating fingerprint for track %1.")
- .tqarg(m_tracks.current()->trackNumber()), INFO );
+ .arg(m_tracks.current()->trackNumber()), INFO );
m_trmJob->start();
}
@@ -215,7 +215,7 @@ void K3bMusicBrainzJob::slotTrmJobFinished( bool success )
// now query musicbrainz
m_mbThread->setSignature( m_trmThread->signature() );
emit infoMessage( i18n("Querying MusicBrainz for track %1.")
- .tqarg(m_tracks.current()->trackNumber()), INFO );
+ .arg(m_tracks.current()->trackNumber()), INFO );
m_mbJob->start();
}
else {
@@ -253,8 +253,8 @@ void K3bMusicBrainzJob::slotMbJobFinished( bool success )
if( resultStringsUnique.count() > 1 )
s = KInputDialog::getItem( i18n("MusicBrainz Query"),
i18n("Found multiple matches for track %1 (%2). Please select one.")
- .tqarg(m_tracks.current()->trackNumber())
- .tqarg(m_tracks.current()->firstSource()->sourceComment()),
+ .arg(m_tracks.current()->trackNumber())
+ .arg(m_tracks.current()->firstSource()->sourceComment()),
resultStringsUnique,
0,
false,
@@ -273,7 +273,7 @@ void K3bMusicBrainzJob::slotMbJobFinished( bool success )
// query next track
if( m_tracks.next() ) {
emit infoMessage( i18n("Generating fingerprint for track %1.")
- .tqarg(m_tracks.current()->trackNumber()), INFO );
+ .arg(m_tracks.current()->trackNumber()), INFO );
m_trmThread->track = m_tracks.current();
m_trmJob->start();
}
diff --git a/src/projects/k3bprojectburndialog.cpp b/src/projects/k3bprojectburndialog.cpp
index 66bd61a..f66ea9b 100644
--- a/src/projects/k3bprojectburndialog.cpp
+++ b/src/projects/k3bprojectburndialog.cpp
@@ -199,10 +199,10 @@ void K3bProjectBurnDialog::slotStartClicked()
//
TQString tempDir = m_tempDirSelectionWidget->tempDirectory();
if( !TQFile::exists( tempDir ) ) {
- if( KMessageBox::warningYesNo( this, i18n("Image folder '%1' does not exist. Do you want K3b to create it?").tqarg( tempDir ) )
+ if( KMessageBox::warningYesNo( this, i18n("Image folder '%1' does not exist. Do you want K3b to create it?").arg( tempDir ) )
== KMessageBox::Yes ) {
if( !KStandardDirs::makeDir( tempDir ) ) {
- KMessageBox::error( this, i18n("Failed to create folder '%1'.").tqarg( tempDir ) );
+ KMessageBox::error( this, i18n("Failed to create folder '%1'.").arg( tempDir ) );
return;
}
}
diff --git a/src/projects/k3bvcdburndialog.cpp b/src/projects/k3bvcdburndialog.cpp
index 98354f9..199b578 100644
--- a/src/projects/k3bvcdburndialog.cpp
+++ b/src/projects/k3bvcdburndialog.cpp
@@ -69,7 +69,7 @@ K3bVcdBurnDialog::K3bVcdBurnDialog( K3bVcdDoc* _doc, TQWidget *parent, const cha
}
setTitle( vcdType, i18n( "1 MPEG (%1)", "%n MPEGs (%1)",
- m_vcdDoc->tracks() ->count() ).tqarg( KIO::convertSize( m_vcdDoc->size() ) ) );
+ m_vcdDoc->tracks() ->count() ).arg( KIO::convertSize( m_vcdDoc->size() ) ) );
const K3bExternalBin* cdrecordBin = k3bcore->externalBinManager() ->binObject( "cdrecord" );
if ( cdrecordBin && cdrecordBin->hasFeature( "cuefile" ) )
@@ -95,13 +95,13 @@ K3bVcdBurnDialog::K3bVcdBurnDialog( K3bVcdDoc* _doc, TQWidget *parent, const cha
// ToolTips
// -------------------------------------------------------------------------
TQToolTip::add
- ( m_radioVcd11, i18n( "Select Video CD type %1" ).tqarg( "(VCD 1.1)" ) );
+ ( m_radioVcd11, i18n( "Select Video CD type %1" ).arg( "(VCD 1.1)" ) );
TQToolTip::add
- ( m_radioVcd20, i18n( "Select Video CD type %1" ).tqarg( "(VCD 2.0)" ) );
+ ( m_radioVcd20, i18n( "Select Video CD type %1" ).arg( "(VCD 2.0)" ) );
TQToolTip::add
- ( m_radioSvcd10, i18n( "Select Video CD type %1" ).tqarg( "(SVCD 1.0)" ) );
+ ( m_radioSvcd10, i18n( "Select Video CD type %1" ).arg( "(SVCD 1.0)" ) );
TQToolTip::add
- ( m_radioHqVcd10, i18n( "Select Video CD type %1" ).tqarg( "(HQ-VCD 1.0)" ) );
+ ( m_radioHqVcd10, i18n( "Select Video CD type %1" ).arg( "(HQ-VCD 1.0)" ) );
TQToolTip::add
( m_checkAutoDetect, i18n( "Automatic video type recognition." ) );
TQToolTip::add
@@ -231,7 +231,7 @@ K3bVcdBurnDialog::K3bVcdBurnDialog( K3bVcdDoc* _doc, TQWidget *parent, const cha
( m_editCdiCfg, i18n( "<p>Configuration parameters only available for VideoCD 2.0"
"<p>The engine works perfectly well when used as-is."
"<p>You have the option to configure the VCD application."
- "<p>You can adapt the color and/or the tqshape of the cursor and lots more." ) );
+ "<p>You can adapt the color and/or the shape of the cursor and lots more." ) );
TQWhatsThis::add
@@ -451,7 +451,7 @@ void K3bVcdBurnDialog::setupVideoCdTab()
m_checkNonCompliant->setEnabled( false );
m_checkNonCompliant->setChecked( false );
- m_checkVCD30interpretation = new TQCheckBox( i18n( "Enable %1 track interpretation" ).tqarg( "VCD 3.0" ), m_groupOptions );
+ m_checkVCD30interpretation = new TQCheckBox( i18n( "Enable %1 track interpretation" ).arg( "VCD 3.0" ), m_groupOptions );
// Only available on SVCD Type
m_checkVCD30interpretation->setEnabled( false );
m_checkVCD30interpretation->setChecked( false );
@@ -580,7 +580,7 @@ void K3bVcdBurnDialog::slotStartClicked()
{
if ( TQFile::exists( vcdDoc() ->vcdImage() ) ) {
- if ( KMessageBox::warningContinueCancel( this, i18n( "Do you want to overwrite %1" ).tqarg( vcdDoc() ->vcdImage() ), i18n( "File Exists" ), i18n("Overwrite") )
+ if ( KMessageBox::warningContinueCancel( this, i18n( "Do you want to overwrite %1" ).arg( vcdDoc() ->vcdImage() ), i18n( "File Exists" ), i18n("Overwrite") )
!= KMessageBox::Continue )
return ;
}
@@ -895,7 +895,7 @@ void K3bVcdBurnDialog::saveCdiConfig()
int i = m_editCdiCfg->numLines();
for ( int j = 0; j < i; j++ )
- s << TQString( "%1" ).tqarg( m_editCdiCfg->textLine( j ) ) << "\n";
+ s << TQString( "%1" ).arg( m_editCdiCfg->textLine( j ) ) << "\n";
cdi.close();
diff --git a/src/projects/k3bvcdlistview.cpp b/src/projects/k3bvcdlistview.cpp
index 3232384..19f49fb 100644
--- a/src/projects/k3bvcdlistview.cpp
+++ b/src/projects/k3bvcdlistview.cpp
@@ -198,7 +198,7 @@ void K3bVcdListView::showPropertiesDialog()
TQPtrList<K3bVcdTrack> tracks = *m_doc->tracks();
K3bVcdTrackDialog d( m_doc, tracks, selected, this );
if ( d.exec() ) {
- tqrepaint();
+ repaint();
}
} else {
m_view->slotProperties();
diff --git a/src/projects/k3bvcdtrackdialog.cpp b/src/projects/k3bvcdtrackdialog.cpp
index bfac930..5a13991 100644
--- a/src/projects/k3bvcdtrackdialog.cpp
+++ b/src/projects/k3bvcdtrackdialog.cpp
@@ -70,7 +70,7 @@ K3bVcdTrackDialog::K3bVcdTrackDialog( K3bVcdDoc* _doc, TQPtrList<K3bVcdTrack>& t
m_displayFileName->setText( selectedTrack->fileName() );
m_displayLength->setText( selectedTrack->duration() );
m_displaySize->setText( KIO::convertSize( selectedTrack->size() ) );
- m_muxrate->setText( i18n( "%1 bit/s" ).tqarg( selectedTrack->muxrate() ) );
+ m_muxrate->setText( i18n( "%1 bit/s" ).arg( selectedTrack->muxrate() ) );
if ( selectedTrack->isSegment() )
m_labelMimeType->setPixmap( SmallIcon( "image", KIcon::SizeMedium ) );
@@ -93,7 +93,7 @@ void K3bVcdTrackDialog::slotOk()
void K3bVcdTrackDialog::setPbcTrack( K3bVcdTrack* selected, K3bCutComboBox* box, int which )
{
// TODO: Unset Userdefined on default settings
- kdDebug() << TQString( "K3bVcdTrackDialog::setPbcTrack: currentItem = %1, count = %2" ).tqarg( box->currentItem() ).tqarg( m_tracks.count() ) << endl;
+ kdDebug() << TQString( "K3bVcdTrackDialog::setPbcTrack: currentItem = %1, count = %2" ).arg( box->currentItem() ).arg( m_tracks.count() ) << endl;
int count = m_tracks.count();
@@ -402,7 +402,7 @@ void K3bVcdTrackDialog::prepareGui()
m_displayLength->setAlignment( int( TQLabel::AlignVCenter | TQLabel::AlignRight ) );
m_muxrate = new TQLabel( groupFileInfo, "m_muxrate" );
- m_muxrate->setText( i18n( "%1 bit/s" ).tqarg( 0 ) );
+ m_muxrate->setText( i18n( "%1 bit/s" ).arg( 0 ) );
m_muxrate->setAlignment( int( TQLabel::AlignVCenter | TQLabel::AlignRight ) );
TQFrame* fileInfoLine = new TQFrame( groupFileInfo );
@@ -744,9 +744,9 @@ TQString K3bVcdTrackDialog::displayName( K3bVcdTrack * track )
return i18n( "ItSelf" );
if ( track->isSegment() )
- return i18n( "Segment-%1 - %2" ).tqarg( TQString::number( track->index() + 1 ).rightJustify( 3, '0' ) ).tqarg( track->title() );
+ return i18n( "Segment-%1 - %2" ).arg( TQString::number( track->index() + 1 ).rightJustify( 3, '0' ) ).arg( track->title() );
- return i18n( "Sequence-%1 - %2" ).tqarg( TQString::number( track->index() + 1 ).rightJustify( 3, '0' ) ).tqarg( track->title() );
+ return i18n( "Sequence-%1 - %2" ).arg( TQString::number( track->index() + 1 ).rightJustify( 3, '0' ) ).arg( track->title() );
}
void K3bVcdTrackDialog::slotPlayTimeChanged( int value )
diff --git a/src/projects/k3bvideodvdburndialog.cpp b/src/projects/k3bvideodvdburndialog.cpp
index c5adefb..32bdefa 100644
--- a/src/projects/k3bvideodvdburndialog.cpp
+++ b/src/projects/k3bvideodvdburndialog.cpp
@@ -46,7 +46,7 @@ K3bVideoDvdBurnDialog::K3bVideoDvdBurnDialog( K3bVideoDvdDoc* doc, TQWidget *par
{
prepareGui();
- setTitle( i18n("Video DVD Project"), i18n("Size: %1").tqarg( KIO::convertSize(doc->size()) ) );
+ setTitle( i18n("Video DVD Project"), i18n("Size: %1").arg( KIO::convertSize(doc->size()) ) );
// for now we just put the verify checkbox on the main page...
m_checkVerify = K3bStdGuiItems::verifyCheckBox( m_optionGroup );
@@ -181,7 +181,7 @@ void K3bVideoDvdBurnDialog::slotStartClicked()
if( TQFile::exists( m_tempDirSelectionWidget->tempPath() ) ) {
if( KMessageBox::warningContinueCancel( this,
- i18n("Do you want to overwrite %1?").tqarg(m_tempDirSelectionWidget->tempPath()),
+ i18n("Do you want to overwrite %1?").arg(m_tempDirSelectionWidget->tempPath()),
i18n("File Exists"), i18n("Overwrite") )
== KMessageBox::Continue ) {
// delete the file here to avoid problems with free space in K3bProjectBurnDialog::slotStartClicked
diff --git a/src/projects/k3baudioeditorwidget.cpp b/src/projects/k3baudioeditorwidget.cpp
index 843d72e..ed17c01 100644
--- a/src/projects/k3baudioeditorwidget.cpp
+++ b/src/projects/k3baudioeditorwidget.cpp
@@ -125,7 +125,7 @@ protected:
if( m ) {
r.setLeft( p.x() - 1 );
r.setRight( p.x() + 1 );
- tip( r, m->toolTip.isEmpty() ? m->pos.toString() : TQString("%1 (%2)").tqarg(m->toolTip).tqarg(m->pos.toString()) );
+ tip( r, m->toolTip.isEmpty() ? m->pos.toString() : TQString("%1 (%2)").arg(m->toolTip).arg(m->pos.toString()) );
}
else {
Range* range = m_editorWidget->findRange( p );
@@ -134,8 +134,8 @@ protected:
r.setRight( m_editorWidget->msfToPos( range->end ) );
tip( r,
range->toolTip.isEmpty()
- ? TQString("%1 - %2").tqarg(range->start.toString()).tqarg(range->end.toString())
- : TQString("%1 (%2 - %3)").tqarg(range->toolTip).tqarg(range->start.toString()).tqarg(range->end.toString()) );
+ ? TQString("%1 - %2").arg(range->start.toString()).arg(range->end.toString())
+ : TQString("%1 (%2 - %3)").arg(range->toolTip).arg(range->start.toString()).arg(range->end.toString()) );
}
}
}
@@ -263,7 +263,7 @@ bool K3bAudioEditorWidget::allowOverlappingRanges() const
void K3bAudioEditorWidget::enableRangeSelection( bool b )
{
d->rangeSelectionEnabled = b;
- tqrepaint( false );
+ repaint( false );
}
@@ -283,7 +283,7 @@ void K3bAudioEditorWidget::setSelectedRange( K3bAudioEditorWidget::Range* r )
{
d->selectedRange = r;
if( rangeSelectedEnabled() ) {
- tqrepaint( false );
+ repaint( false );
emit selectedRangeChanged( d->selectedRange ? d->selectedRange->id : 0 );
}
}
@@ -356,7 +356,7 @@ bool K3bAudioEditorWidget::modifyRange( int identifier, const K3b::Msf& start, c
if( !d->allowOverlappingRanges )
fixupOverlappingRanges( range );
- tqrepaint( false );
+ repaint( false );
return true;
}
@@ -372,7 +372,7 @@ bool K3bAudioEditorWidget::removeRange( int identifier )
emit rangeRemoved( identifier );
// tqrepaint only the part of the range
TQRect rect = contentsRect();
rect.setLeft( msfToPos( range->start ) );
rect.setRight( msfToPos( range->end ) );
@@ -491,7 +491,7 @@ void K3bAudioEditorWidget::drawContents( TQPainter* p )
pix.fill( colorGroup().base() );
TQPainter pixP;
- pixP.tqbegin( &pix, TQT_TQOBJECT(this) );
+ pixP.begin( &pix, TQT_TQOBJECT(this) );
TQRect drawRect( contentsRect() );
drawRect.setLeft( drawRect.left() + m_margin );
@@ -690,11 +690,11 @@ void K3bAudioEditorWidget::mouseReleaseEvent( TQMouseEvent* e )
//
if( m_draggedRange ) {
fixupOverlappingRanges( m_draggedRange );
- tqrepaint( false );
+ repaint( false );
}
else if( d->movedRange ) {
fixupOverlappingRanges( d->movedRange );
- tqrepaint( false );
+ repaint( false );
}
}
@@ -739,13 +739,13 @@ void K3bAudioEditorWidget::mouseMoveEvent( TQMouseEvent* e )
emit rangeChanged( m_draggedRange->id, m_draggedRange->start, m_draggedRange->end );
- tqrepaint( false );
+ repaint( false );
}
else if( m_draggedMarker ) {
m_draggedMarker->pos = posToMsf( e->pos().x() );
emit markerMoved( m_draggedMarker->id, m_draggedMarker->pos );
- tqrepaint( false );
+ repaint( false );
}
else if( d->movedRange ) {
int diff = posToMsf( e->pos().x() ).lba() - d->lastMovePosition.lba();
@@ -763,7 +763,7 @@ void K3bAudioEditorWidget::mouseMoveEvent( TQMouseEvent* e )
emit rangeChanged( d->movedRange->id, d->movedRange->start, d->movedRange->end );
- tqrepaint( false );
+ repaint( false );
}
}
else if( findRangeEdge( e->pos() ) || findMarker( e->pos() ) )
@@ -372,7 +372,7 @@ bool K3bAudioEditorWidget::removeRange( int identifier )
emit rangeRemoved( identifier );
- // tqrepaint only the part of the range
+ // repaint only the part of the range
TQRect rect = contentsRect();
rect.setLeft( msfToPos( range->start ) );